#pragma once

#include <cstddef>
#include <memory>
#include <string>

namespace AMDiS
{
  template <class T>
  struct Triplet
  {
    std::size_t row, col;
    T value;
  };

  template <class Basis>
  class DefaultCommunication
  {
  public:
    static std::unique_ptr<DefaultCommunication> create(Basis const& basis, std::string const& prefix)
    {
      DUNE_UNUSED_PARAMETER(basis);
      DUNE_UNUSED_PARAMETER(prefix);
      return std::make_unique<DefaultCommunication>();
    }
  };

  /** Base traits class for a linear solver for the system AX=B using an FE space described by a
   *  dune-functions Basis. This defines the general interface typedefs, all implementations are
   *  required to provide the typedefs listed here, by e.g. inheriting from this.
   */
  template <class A, class X, class B, class Basis>
  class SolverTraitsBase
  {
  public:
    using Mat = A;
    using Sol = X;
    using Rhs = B;
    using Comm = DefaultCommunication<Basis>;
  };

} // end namespace AMDiS
